@@ -352,7 +352,7 @@ namespace orc {
     const char* expected = "XXXXabcdabcdABCDABCDwxyzwzyz123";
     ASSERT_EQ(strlen(expected), length);
     for (uint64_t i = 0; i < length; ++i) {
-      ASSERT_EQ(static_cast<const char>(expected[i]), static_cast<const char*>(ptr)[i]);
+      ASSERT_EQ(static_cast<char>(expected[i]), static_cast<const char*>(ptr)[i]);
     }
     ASSERT_TRUE(!result->Next(&ptr, &length));
   }
@@ -395,26 +395,6 @@ namespace orc {
     ASSERT_TRUE(!result->Next(&ptr, &length));
   }
 
-  TEST_F(TestDecompression, testLzoOverflow) {
-    const unsigned char bad_lzo_data[] = {// Header: compressedSize = 12, original = false
-                                          0x18, 0x00, 0x00,
-
-                                          // LZO body: token and literal length extension
-                                          0x00,  // token: extended literal length
-                                          0xFF,  // extension byte 1
-
-                                          // Literal data: only 10 bytes far less than 273
-                                          'A', 'A', 'A', 'A', 'A', 'A', 'A', 'A', 'A', 'A'};
-
-    std::unique_ptr<SeekableInputStream> result = createDecompressor(
-        CompressionKind_LZO,
-        std::make_unique<SeekableArrayInputStream>(bad_lzo_data, ARRAY_SIZE(bad_lzo_data)),
-        128 * 1024, *getDefaultPool(), getDefaultReaderMetrics());
-    const void* ptr;
-    int length;
-    EXPECT_THROW(result->Next(&ptr, &length), ParseError);
-  }
-
   TEST_F(TestDecompression, testLz4Empty) {
     const unsigned char buffer[] = {0};
     std::unique_ptr<SeekableInputStream> result = createDecompressor(
@@ -439,7 +419,7 @@ namespace orc {
     const char* expected = "XXXXabcdabcdABCDABCDwxyzwzyz123";
     ASSERT_EQ(strlen(expected), length);
     for (uint64_t i = 0; i < length; ++i) {
-      ASSERT_EQ(static_cast<const char>(expected[i]), static_cast<const char*>(ptr)[i]);
+      ASSERT_EQ(static_cast<char>(expected[i]), static_cast<const char*>(ptr)[i]);
     }
     ASSERT_TRUE(!result->Next(&ptr, &length));
   }
