@@ -555,11 +555,6 @@ namespace orc {
 
     num = Int128("-12345678901122334455667788990011122233");
     EXPECT_EQ("-12345678901122334455667788990011122233", num.toString());
-
-    num = Int128::maximumValue();
-    EXPECT_EQ("170141183460469231731687303715884105727", num.toString());
-    num = Int128::minimumValue();
-    EXPECT_EQ("-170141183460469231731687303715884105728", num.toString());
   }
 
   TEST(Int128, testToDecimalString) {
@@ -1206,4 +1201,39 @@ namespace orc {
         << pair.second.toString();
   }
 
+  TEST(Int128, testConvertToDouble) {
+    // fit in long
+    EXPECT_DOUBLE_EQ(Int128("0").toDouble(), 0);
+    EXPECT_DOUBLE_EQ(Int128("1").toDouble(), 1);
+    EXPECT_DOUBLE_EQ(Int128("-1").toDouble(), -1);
+    EXPECT_DOUBLE_EQ(Int128("-123").toDouble(), -123);
+    EXPECT_DOUBLE_EQ(Int128("123").toDouble(), 123);
+    EXPECT_DOUBLE_EQ(Int128("-123456").toDouble(), -123456);
+    EXPECT_DOUBLE_EQ(Int128("123456").toDouble(), 123456);
+    EXPECT_DOUBLE_EQ(Int128("-123456789").toDouble(), -123456789);
+    EXPECT_DOUBLE_EQ(Int128("123456789").toDouble(), 123456789);
+    EXPECT_DOUBLE_EQ(Int128("-123456789012").toDouble(), -123456789012.0);
+    EXPECT_DOUBLE_EQ(Int128("123456789012").toDouble(), 123456789012.0);
+    EXPECT_DOUBLE_EQ(Int128("-123456789012345").toDouble(), -123456789012345.0);
+    EXPECT_DOUBLE_EQ(Int128("123456789012345").toDouble(), 123456789012345.0);
+    EXPECT_DOUBLE_EQ(Int128("-123456789012345678").toDouble(), -123456789012345678.0);
+    EXPECT_DOUBLE_EQ(Int128("123456789012345678").toDouble(), 123456789012345678.0);
+    EXPECT_DOUBLE_EQ(Int128("-9223372036854775808").toDouble(), -9223372036854775808.0);
+    EXPECT_DOUBLE_EQ(Int128("9223372036854775807").toDouble(), 9223372036854775807.0);
+    // Not fit in long
+    EXPECT_DOUBLE_EQ(Int128("100000000000000000000").toDouble(), 1e20);
+    EXPECT_DOUBLE_EQ(Int128("-100000000000000000000").toDouble(), -1e20);
+    EXPECT_DOUBLE_EQ(Int128("-12345678901234567890").toDouble(), -12345678901234567890.0);
+    EXPECT_DOUBLE_EQ(Int128("-123456789012345678901").toDouble(), -123456789012345678901.0);
+    EXPECT_DOUBLE_EQ(Int128("123456789012345678901").toDouble(), 123456789012345678901.0);
+    EXPECT_DOUBLE_EQ(Int128("-1234567890123456789012").toDouble(), -1234567890123456789012.0);
+    EXPECT_DOUBLE_EQ(Int128("1234567890123456789012").toDouble(), 1234567890123456789012.0);
+    EXPECT_DOUBLE_EQ(Int128("-12345678901234567890123").toDouble(), -12345678901234567890123.0);
+    EXPECT_DOUBLE_EQ(Int128("12345678901234567890123").toDouble(), 12345678901234567890123.0);
+    EXPECT_DOUBLE_EQ(Int128("12345678901234567890123456789").toDouble(),
+                     12345678901234567890123456789.0);
+    EXPECT_DOUBLE_EQ(Int128("-12345678901234567890123456789").toDouble(),
+                     -12345678901234567890123456789.0);
+  }
+
 }  // namespace orc
