@@ -18,6 +18,7 @@
 
 #include "Adaptor.hh"
 #include "Timezone.hh"
+#include "wrap/gmock.h"
 #include "wrap/gtest-wrapper.h"
 
 #include <iostream>
@@ -401,4 +402,21 @@ namespace orc {
     // DST ends in Los Angeles November 5, 2:00 am
     EXPECT_EQ(1699164000 + 8 * 3600, la->convertFromUTC(1699164000));
   }
+
+#ifndef _MSC_VER
+  TEST(TestTimezone, testMissingTZDB) {
+    const char* tzDirBackup = std::getenv("TZDIR");
+    setenv("TZDIR", "/path/to/wrong/tzdb", 1);
+    EXPECT_THAT([]() { getTimezoneByName("America/Los_Angeles"); },
+                testing::ThrowsMessage<TimezoneError>(testing::HasSubstr(
+                    "Time zone file /path/to/wrong/tzdb/America/Los_Angeles does not exist."
+                    " Please install IANA time zone database and set TZDIR env.")));
+    if (tzDirBackup != nullptr) {
+      setenv("TZDIR", tzDirBackup, 1);
+    } else {
+      unsetenv("TZDIR");
+    }
+  }
+#endif
+
 }  // namespace orc
