@@ -704,8 +704,7 @@ public class RecordReaderImpl implements RecordReader {
           predicate.getColumnName(), writerVersion);
       return TruthValue.YES_NO_NULL;
     } else if ((category == TypeDescription.Category.DOUBLE ||
-        category == TypeDescription.Category.FLOAT) && cs instanceof DoubleColumnStatistics) {
-      DoubleColumnStatistics dstas = (DoubleColumnStatistics) cs;
+        category == TypeDescription.Category.FLOAT) && cs instanceof DoubleColumnStatistics dstas) {
       if (Double.isNaN(dstas.getSum())) {
         LOG.debug("Not using predication pushdown on {} because stats contain NaN values",
                 predicate.getColumnName());
@@ -766,13 +765,6 @@ public class RecordReaderImpl implements RecordReader {
     if (!range.hasValues()) {
       if (predicate.getOperator() == PredicateLeaf.Operator.IS_NULL) {
         return TruthValue.YES;
-      } else if (predicate.getOperator() == PredicateLeaf.Operator.NULL_SAFE_EQUALS) {
-        Object literal = predicate.getLiteral();
-        if (literal == null) {
-          return TruthValue.YES;
-        } else {
-          return TruthValue.NO;
-        }
       } else {
         return TruthValue.NULL;
       }
@@ -1065,8 +1057,7 @@ public class RecordReaderImpl implements RecordReader {
         }
         break;
       case STRING:
-        if (obj instanceof ChronoLocalDate) {
-          ChronoLocalDate date = (ChronoLocalDate) obj;
+        if (obj instanceof ChronoLocalDate date) {
           return date.format(DateTimeFormatter.ISO_LOCAL_DATE
               .withChronology(date.getChronology()));
         }
