@@ -285,9 +285,9 @@ public class TestFileDump {
       writer.addRowBatch(batch);
     }
     writer.addUserMetadata("hive.acid.key.index",
-      StandardCharsets.UTF_8.encode("1,1,1;2,3,5;"));
+        StandardCharsets.UTF_8.encode("1,1,1;2,3,5;"));
     writer.addUserMetadata("some.user.property",
-      StandardCharsets.UTF_8.encode("foo#bar$baz&"));
+        StandardCharsets.UTF_8.encode("foo#bar$baz&"));
     writer.close();
     assertEquals(2079000, writer.getRawDataSize());
     assertEquals(21000, writer.getNumberOfRows());
@@ -334,7 +334,7 @@ public class TestFileDump {
             format.parse("2014-11-25 00:00:00").getTime())),
         "string",
         "hello",
-       "hello",
+        "hello",
         m,
         Arrays.asList(100, 200),
         10, "foo");
@@ -588,6 +588,7 @@ public class TestFileDump {
     Writer writer = OrcFile.createWriter(testFilePath,
         OrcFile.writerOptions(conf)
             .setSchema(schema)
+            .compress(CompressionKind.ZLIB)
             .rowIndexStride(1000)
             .stripeSize(10000)
             .bufferSize(10000));
@@ -816,11 +817,11 @@ public class TestFileDump {
     ByteArrayOutputStream myOut = new ByteArrayOutputStream();
 
     // replace stdout and run command
-    System.setOut(new PrintStream(myOut, false, StandardCharsets.UTF_8.toString()));
+    System.setOut(new PrintStream(myOut, false, StandardCharsets.UTF_8));
     FileDump.main(new String[]{testFilePath.toString(), "-d"});
     System.out.flush();
     System.setOut(origOut);
-    String[] lines = myOut.toString(StandardCharsets.UTF_8.toString()).split("\n");
+    String[] lines = myOut.toString(StandardCharsets.UTF_8).split("\n");
     assertEquals("{\"x\":NaN}", lines[0]);
     assertEquals("{\"x\":Infinity}", lines[1]);
     assertEquals("{\"x\":12.34}", lines[2]);
